@@ -63,7 +63,7 @@ struct _GisPageClass
   gboolean     (*save_data) (GisPage  *page,
                              GError  **error);
   void         (*shown) (GisPage *page);
-  gboolean     (*skip) (GisPage *page);
+  void         (*skip) (GisPage *page);
 };
 
 GType gis_page_get_type (void);
@@ -76,6 +76,8 @@ gboolean     gis_page_get_skippable (GisPage *page);
 void         gis_page_set_skippable (GisPage *page, gboolean skippable);
 gboolean     gis_page_get_needs_accept (GisPage *page);
 void         gis_page_set_needs_accept (GisPage *page, gboolean needs_accept);
+gboolean     gis_page_get_has_forward (GisPage *page);
+void         gis_page_set_has_forward (GisPage *page, gboolean has_forward);
 void         gis_page_locale_changed (GisPage *page);
 void         gis_page_apply_begin (GisPage *page, GisPageApplyCallback callback, gpointer user_data);
 void         gis_page_apply_cancel (GisPage *page);
@@ -84,7 +86,7 @@ gboolean     gis_page_get_applying (GisPage *page);
 gboolean     gis_page_save_data (GisPage  *page,
                                  GError  **error);
 void         gis_page_shown (GisPage *page);
-gboolean     gis_page_skip (GisPage *page);
+void         gis_page_skip (GisPage *page);
 
 G_END_DECLS
 
